@@ -40,13 +40,16 @@ This is the author of the BZR repository from which VM was released.")
       (let* ((f (locate-library "vm"))
              (d (file-name-directory f))
              (b (get-buffer " *vm-version*"))
-	     (devo (file-exists-p (expand-file-name ".bzr" (concat d "../"))))
-	     (bzr (or (locate-file "bzr.exe" exec-path)
-		      (locate-file "bzr.bat" exec-path)
-		      (locate-file "bzr" exec-path))))
+	     (bzrdir (expand-file-name ".bzr" (concat d "../")))
+	     (bzr (and (file-exists-p bzrdir)
+		       (if (functionp 'locate-file)
+			   (or (locate-file "bzr.exe" exec-path)
+			       (locate-file "bzr.bat" exec-path)
+			       (locate-file "bzr" exec-path))
+			 "bzr"))))
         (setq default-directory d)
         (erase-buffer)
-        (cond ((and devo bzr 
+        (cond ((and bzr 
 		    (condition-case nil
 			(= 0 (call-process bzr nil b))
 		      (error nil)))
@@ -55,7 +58,9 @@ This is the author of the BZR repository from which VM was released.")
 	       (call-process bzr nil b nil "--no-aliases" "--no-plugins" "nick") 
 	       (insert "-")
 	       (call-process bzr nil b nil "--no-aliases" "--no-plugins" "revno"))
-              ((and (not devo) (locate-library "vm-revno") (load-library "vm-revno"))
+              ((and (not bzr) 
+		    (locate-library "vm-revno") 
+		    (load-library "vm-revno"))
                (insert vm-revno))
               (t
                (insert "?bug?")
